#
# spec file for package nestopia
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2018-2024, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           nestopia
Version:        1.52.1
Release:        1.1
Summary:        Nintendo Entertainment System/Famicom emulator
License:        GPL-2.0-or-later
Group:          System/Emulators/Other
URL:            https://github.com/0ldsk00l/nestopia
#Git-Clone:     https://github.com/0ldsk00l/nestopia.git
Source:         https://github.com/0ldsk00l/%{name}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  autoconf-archive
BuildRequires:  automake
BuildRequires:  fltk-devel
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(epoxy)
BuildRequires:  pkgconfig(libarchive)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(zlib)

%description
Nestopia is a cycle-accurate NES/Famicom emulator. It has a high compatibility
rate and support for many peripherals and input devices.

%prep
%setup -q
sed -i 's/\r$//' ChangeLog

%build
autoreconf -fiv
%configure \
  --docdir=%{_docdir}/%{name} \
  --enable-gui \
  --enable-doc
%make_build

%install
%make_install

%check

%files
%license COPYING
%doc ChangeLog readme.html README.md
%{_docdir}/%{name}
%{_bindir}/%{name}
%{_datadir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_datadir}/icons/hicolor/scalable/apps/nespad.svg
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg

%changelog
* Tue Apr  2 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 1.52.1
  Changes:
  * FLTK: Allow loading more compressed file types.
  Fixes:
  * FLTK: Fix text drawing time calculation.
  * FLTK: Clean up input code, use callbacks for polling input.
  Core:
  Additions:
  * Support for Mapper 81 (NTDEC N715021).
  * Support for Mapper 227.1 (BMC 120-IN-1).
  * Support for Mapper 354 (submapper 0 and 1).
  * Zapper support for Fruit Shinobi (EstebenZapataME).
  * New palettes from HighNES and FBX.
  Fixes:
  * Pass sprdma_and_dmc_dma and sprdma_and_dmc_dma_512 tests.
  * CHR banking in TxcPoliceman - Policeman (Spain) (En) (Gluk
    Video) (Unl).
  * Increase maximum PRG size for VRC2 to handle modern VRC2 hacks
  * Simplify MMC5 heuristics to better handle newer hacks and
    homebrew.
  * Fix mirroring glitch in mapper 156.
* Mon Jan  2 2023 Dirk Müller <dmueller@suse.com>
- update to 1.52.0:
  - FLTK: Update to latest lodepng
  - FLTK: Use NST prefix for data directories in build (cpasjuste)
  - FLTK: Better frame timing on non-60Hz screens
  - win32: Fix minor code problems (mjunix)
  - Add support for Unlicensed MMC3 boards with PRG ROM over 512K
  - Add support for Mapper 258 (UNL-158B)
  - Add support for Mapper 400 (UNL-RET-X7-GBL)
  - Remove options for 8-bit audio and sample rates below 44100Hz
  - Improve heuristics for VRC2/4 boards
  - Fix IPS patching in cases where patches overlap ROM region boundaries
  - Improve handling of fast sequential reads to 0x2007
  - Improve opcode 9c and 9e timing
  - Correct implementation of PPU Open Bus
* Fri Aug 27 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.51.1
  Fixes:
  * FLTK: Better audio buffer management
  * FLTK: Fix bug related to system-wide NstDatabase.xml loading
  Additions:
  * Mappers 162, 302, 554 (UNL-FS304, UNL-KS7057, UNL-KS7010)
  * Add database entries for Micro Mages, Nong Chang Xiao Jing Ling
  Fixes:
  * Accuracy fix for MMC3 and MMC6 IRQ timing
  * Accuracy fix for DMC DMA read conflicts
  * Accuracy fix for CPU Exec Space PPUIO
* Sat Jul 17 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.51
  Changes:
  * Merged the win32 sources back into the main codebase
  * Switch from GTK to FLTK for Linux/BSD port
  * Use Legacy OpenGL (Compatibility Profile)
  Additions:
  * Mappers 306, 307, 312
  * Convert many UNIF boards to NES 2.0 mappers
  Changes:
  * Use Nestopia core from jgemu
  Fixes:
  * Timing and other accuracy fixes for CPU/APU
  * Revert changes that caused regressions
  * Fix Camerica mapper for Dooly Bravo Land
  * Improve MMC5 emulation for Sim City
  * Fix 8K PRG NROM games such as Galaxian
  * Full implementation of mapper 156
  * Fix SOROM saving/loading
  * Fix FDS IRQ behaviour
  * Improve RAMBO-1 timing
  * Fix support for Korean Igo (Korea) (Unl)
  * Implement mirroring for UNL-KOF97
  * Rewrite NAMCOT-175 and NAMCOT-340
  * Assign UNL-CC-21 to mapper 27 and fix CHR bank swapping
* Sun Jan  5 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.50
  Additions:
  * Added ability to output data from homebrew module
  libretro:
  Additions:
    + Button shift option
    + Input bitmask support
    + Enhanced core options
    + Build in NstDatabase.xml
  Core:
  Additions:
    + Support for mapper 31
    + Support for mappers 28 and 30
    + Support for UNL-KS7031
    + Support for MMC3 Big CHR-RAM Board
  Fixes:
    + Deterministic Save States
* Sat Aug 18 2018 mardnh@gmx.de
- Fix license tag
* Sun Aug  5 2018 mardnh@gmx.de
- Initial package, version 1.49
